--- loncom/publisher/lonupload.pm	2001/11/29 21:51:40	1.8
+++ loncom/publisher/lonupload.pm	2002/08/08 02:30:39	1.12
@@ -1,7 +1,8 @@
+
 # The LearningOnline Network with CAPA
 # Handler to upload files into construction space
 #
-# $Id: lonupload.pm,v 1.8 2001/11/29 21:51:40 matthew Exp $
+# $Id: lonupload.pm,v 1.12 2002/08/08 02:30:39 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -31,9 +32,11 @@
 # 
 # (TeX Content Handler
 #
+# YEAR=2000
 # 05/29/00,05/30,10/11 Gerd Kortemeyer)
 #
 # 11/28,11/29,11/30,12/01,12/02,12/04,12/23 Gerd Kortemeyer
+# YEAR=2001
 # 03/23 Guy Albertelli
 # 03/24,03/29 Gerd Kortemeyer)
 #
@@ -41,6 +44,9 @@
 #
 # 04/05,04/09,05/25,06/23,06/24,08/22 Gerd Kortemeyer
 # 11/29 Matthew Hall
+# 12/16 Scott Harrison
+#
+###
 
 package Apache::lonupload;
 
@@ -49,7 +55,25 @@ use Apache::File;
 use File::Copy;
 use Apache::Constants qw(:common :http :methods);
 use Apache::loncacc;
-use Apache::lonnet;
+use Apache::loncommon();
+use Apache::Log();
+
+my $DEBUG=0;
+
+sub Debug {
+  
+  # Marshall the parameters.
+  
+  my $r       = shift;
+  my $log     = $r->log;
+  my $message = shift;
+  
+  # Put out the indicated message butonly if DEBUG is false.
+  
+  if ($DEBUG) {
+    $log->debug($message);
+  }
+}
 
 sub upfile_store {
     my $r=shift;
@@ -80,7 +104,8 @@ sub phaseone {
     $fn.=$ENV{'form.upfile.filename'};
     $fn=~s/^\///;
     $fn=~s/(\/)+/\//g;
-
+    $fn=~s/%20/ /g;
+    &Debug($r, "Filename for upload: $fn");
     if (($fn) && ($fn!~/\/$/)) {
       $r->print(
  '<form action=/adm/upload method=post>'.
@@ -90,16 +115,24 @@ sub phaseone {
  '<input type=text size=50 name=filename value="/priv/'.
   $uname.'/'.$fn.'"><br>'.
  '<input type=submit value="Store"></form>');
-      # Check for bad extension
+      # Check for bad extension and warn user
       if ($fn=~/\.(\w+)$/ && 
-	  (&Apache::lonnet::fileembstyle($1) eq 'hdn')) {
+	  (&Apache::loncommon::fileembstyle($1) eq 'hdn')) {
 	  $r->print(
  '<font color=red>'.
  'The extension on this file, "'.$1.
  '", is reserved internally by LON-CAPA. <br \>'.
  'Please change the extension.'.
  '</font>');
-      }  
+      } elsif($fn=~/\.(\w+)$/ && 
+	      !defined(&Apache::loncommon::fileembstyle($1))) {
+	  $r->print(
+ '<font color=red>'.
+ 'The extension on this file, "'.$1.
+ '", is not recognized by LON-CAPA. <br \>'.
+ 'Please change the extension.'.
+ '</font>');
+      }
   } else {
       $r->print('<font color=red>Illegal filename.</font>');
   }
@@ -127,15 +160,23 @@ sub phasetwo {
        } else {
            my $source=$r->dir_config('lonDaemons').
 	                             '/tmp/'.$datatoken.'.tmp';
            # Check for bad extension
 	   if ($fn=~/\.(\w+)$/ && 
-	       (&Apache::lonnet::fileembstyle($1) eq 'hdn')) {
+	       (&Apache::loncommon::fileembstyle($1) eq 'hdn')) {
 	       $r->print(
  'File <tt>'.$fn.'</tt> could not be copied.<br />'.
  '<font color=red>'.
  'The extension on this file is reserved internally by LON-CAPA.'.
  '</font>');
+	   } elsif ($fn=~/\.(\w+)$/ && 
+		    !defined(&Apache::loncommon::fileembstyle($1))) {
+	       $r->print(
+ 'File <tt>'.$fn.'</tt> could not be copied.<br />'.
+ '<font color=red>'.
+ 'The extension on this file is not recognized by LON-CAPA.'.
+ '</font>');
 	   } elsif (copy($source,$target)) {
+	       chmod(0660, $target); # Set permissions to rw-rw---.
 	      $r->print('File copied.');
               $r->print('<p><font size=+2><a href="'.$fn.
                         '">View file</a></font>');
@@ -155,6 +196,7 @@ sub phasetwo {
   }
 }
 
+# ---------------------------------------------------------------- Main Handler
 sub handler {
 
   my $r=shift;
@@ -216,3 +258,76 @@ sub handler {
 
 1;
 __END__
+
+=head1 NAME
+
+Apache::lonupload - upload files into construction space
+
+=head1 SYNOPSIS
+
+Invoked by /etc/httpd/conf/srm.conf:
+
+ <Location /adm/upload>
+ PerlAccessHandler       Apache::lonacc
+ SetHandler perl-script
+ PerlHandler Apache::lonupload
+ ErrorDocument     403 /adm/login
+ ErrorDocument     404 /adm/notfound.html
+ ErrorDocument     406 /adm/unauthorized.html
+ ErrorDocument	  500 /adm/errorhandler
+ </Location>
+
+=head1 INTRODUCTION
+
+This module uploads a file sitting on a client computer into 
+library server construction space.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 HANDLER SUBROUTINE
+
+This routine is called by Apache and mod_perl.
+
+=over 4
+
+=item *
+
+Initialize variables
+
+=item *
+
+Start page output
+
+=item *
+
+output relevant interface phase (phaseone or phasetwo)
+
+=item *
+
+(phase one is to specify upload file; phase two is to handle conditions
+subsequent to specification--like overwriting an existing file)
+
+=back
+
+=head1 OTHER SUBROUTINES
+
+=over 4
+
+=item *
+
+phaseone() : Interface for specifying file to upload.
+
+=item *
+
+phasetwo() : Interface for handling post-conditions about uploading (such
+as overwriting an existing file).
+
+=item *
+
+upfile_store() : Store contents of uploaded file into temporary space.  Invoked
+by phaseone subroutine.
+
+=back
+
+=cut
@@ -127,15 +160,23 @@ sub phasetwo {
            my $source=$r->dir_config('lonDaemons').
 	                             '/tmp/'.$datatoken.'.tmp';
-           # Check for bad extension
+           # Check for bad extension and disallow upload
 	   if ($fn=~/\.(\w+)$/ && 